@@ -1,5 +1,5 @@
 package WebService::ValidSign::Object::Document;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 use Moo;
 extends 'WebService::ValidSign::Object';
 
@@ -15,10 +15,7 @@ has name => (
     required => 1,
 );
 
-has path => (
-    is       => 'ro',
-    required => 1,
-);
+has path => (is => 'ro');
 
 around TO_JSON => sub {
     my $orig = shift;
@@ -43,7 +40,7 @@ WebService::ValidSign::Object::Document - A ValidSign Document object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
